## 开盘啦题材库

接口：kpl_concept

描述：获取开盘啦概念题材列表，每天盘后更新

限量：单次最大5000条，可根据日期循环获取历史数据

积分：5000积分可提取数据，具体请参阅积分获取办法 

注：开盘啦是一个优秀的专业打板app，有兴趣的用户可以自行下载安装。本接口仅限用于量化研究，如需商业用途，请自行联系开盘APP官方。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期（YYYYMMDD格式） |
| ts_code | str | N | 题材代码（xxxxxx.KP格式） |
| name | str | N | 题材名称 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | 题材代码 |
| name | str | Y | 题材名称 |
| z_t_num | None | Y | 涨停数量 |
| up_num | str | Y | 排名上升位数 |

接口用法

```python
pro = ts.pro_api()

df = pro.kpl_concept(trade_date='20241014')
```

数据样例

```python
trade_date    ts_code     name      z_t_num up_num
0     20241014  000111.KP     化债概念       15      0
```